# Experiment 1: -- normal capitalization (version A)
# boundary manipulation of word n+1
# preview validity:   valid vs. invalid
# preview difficulty: easy (HF) vs. difficult (LF)

# Sarah Risse, May 2012


rm(list=ls())

# INPUT:
q_file <- c("N1FQ_Quest.rda")
s_file <- c("N1FQ_Subjects.rda")
d_file <- c("n1FQ_em_filtered.rda")
a_file <- c("n1FQ_a_filtered.rda")

ofile <- c("/Users/Sarah/Documents/EM_Manuscripts/2012.Article.N1FQ/pmr2/N1FQ_Subjects.rda")
setwd(c("/Users/Sarah/Documents/EM_Manuscripts/2012.Article.N1FQ/pmr2"))


# LIBRARIES:
library(lme4)
library(reshape)


# FUNCTIONS:
source("remef.R")
source("parseq_fast.R")

# LOAD DATA:
load(q_file)	# quest
load(s_file)	# subjects
load(d_file)	# em
load(a_file)	# a




#------------------------------------
# DISPLAY CHANGE DETECTION :
# select participants
#------------------------------------


# (1) select Experiment 1:
#----------------------------

xexp1_in_subj  <- which(subjects$exp==0)  # 29 participants
id_e1 <- subjects$id[xexp1_in_subj]		# id's in Experiment 1
xexp1_in_quest <- match(id_e1,quest$id)
dc_e1 <- quest[xexp1_in_quest,]		# their questionnaire results

# (2) check participants display-change detection sensitivity in Exp.1:
#----------------------------------------------------------------------

length(which(dc_e1$f1==0)) 	# 5 noticed nothing
length(which(dc_e1$f1==1)) 	# 24 noticed something

length(which(dc_e1$f1==1 & dc_e1$f2==3)) # 23 out of 24 noticed display changes

display_change_detection <- dc_e1$f3[which(dc_e1$f1==1 & dc_e1$f2==3)]
hist(display_change_detection, breaks=20)
table(display_change_detection)

length(which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 > 5)) # 16/23 noticed 
# more than 5% (equal to 6) display changes during the experiment
length(which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 <= 5)) # 7/23 noticed 
# less than 5% (equal to 6) display changes during the experiment

# (3) select DC full aware and less aware participants:
#---------------------------------------------------------

dc_faware   <- dc_e1$id[which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 > 5)] 
dc_laware <- setdiff(dc_e1$id, dc_faware)

length(dc_faware)		# 16 participants full aware of display changes
length(dc_laware)		# 13 participants less aware ...

# (4) description of full-aware and less-aware groups:
#--------------------------------------------------------

# FULL AWARE:
range(dc_e1$f3[which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 > 5)])
# 10 - 70 % display changes
mean(dc_e1$f3[which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 > 5)]) # 26%
sd(dc_e1$f3[which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 > 5)])   # 17.3

# LESS AWARE:
range(dc_e1$f3[which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 <= 5)])
# 0 - 5 % display changes
mean(dc_e1$f3[which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 <= 5)]) # 2%
sd(dc_e1$f3[which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 <= 5)])   # 1.6

# (5) select experimental data and add DC information:
#--------------------------------------------------------

#------------------------------------
# for data set "a" (fixation based):
#------------------------------------

val_ids_e1   <- which(is.element(a$id, id_e1)==TRUE)
d <- a[val_ids_e1,] 

# ndcd: ADD NUMBER OF DISPLAY CHANGES PER SUBJECT (in %):
id_dcd <- dc_e1$id[which(dc_e1$f1==1 & dc_e1$f2==3)]
id_ndcd <- dc_e1$f3[which(is.element(dc_e1$id,id_dcd)==T)]
xdc_to_d <- match(d$id, id_dcd)

d$ndcd <- NA
d$ndcd <- id_ndcd[xdc_to_d] 
d$ndcd[which(is.na(d$ndcd)==TRUE)] <- 0 

# gdcd: ADD GROUP OF DISPLAY CHANGES:
# less aware: -0.5
# full aware:  0.5
xla_in_d <- which(is.element(d$id, dc_laware)==TRUE)
xfa_in_d <- which(is.element(d$id, dc_faware)==TRUE)

d$gdcd <- NA
d$gdcd[xla_in_d] <- -0.5   #  less aware
d$gdcd[xfa_in_d] <-  0.5   #  full aware


#------------------------------------
# filter data for target word n+1
#------------------------------------
xt <- which(d$tar==1)
xd_sn_wn    <- 1e2*d$sn + d$wn
xt_sn_wn    <- unique(1e2*d$sn[xt] + d$wn[xt]) # contains 120 target words
xpre_sn_wn  <- xt_sn_wn - 1
xpost_sn_wn <- xt_sn_wn + 1


xTarget     <- which(is.element(xd_sn_wn,xt_sn_wn)==TRUE)
xPretarget  <- which(is.element(xd_sn_wn,xpre_sn_wn)==TRUE)
xPosttarget <- which(is.element(xd_sn_wn,xpost_sn_wn)==TRUE)


d_n1 <- d[xTarget,]
d_n0 <- d[xPretarget,]
d_n2 <- d[xPosttarget,]


#------------------------------------
# for data set "em" (word based):
#------------------------------------

val_ids_e1   <- which(is.element(em$id, id_e1)==TRUE)
e <- em[val_ids_e1,] 

# ndcd: ADD NUMBER OF DISPLAY CHANGES PER SUBJECT (in %):
xdc_to_e <- match(e$id, id_dcd)

e$ndcd <- NA
e$ndcd <- id_ndcd[xdc_to_e] 
e$ndcd[which(is.na(e$ndcd)==TRUE)] <- 0 

# gdcd: ADD GROUP OF DISPLAY CHANGES:
# less aware: -0.5
# full aware:  0.5
xla_in_e <- which(is.element(e$id, dc_laware)==TRUE)
xfa_in_e <- which(is.element(e$id, dc_faware)==TRUE)

e$gdcd <- NA
e$gdcd[xla_in_e] <- -0.5   #  less aware
e$gdcd[xfa_in_e] <-  0.5   #  full aware


#------------------------------------
# filter data for target word n+1
#------------------------------------

xTarget     <- which(e$twx==1)
xPretarget  <- which(e$twx==1)-1
xPosttarget <- which(e$twx==1)+1

e_n1 <- e[xTarget,]
e_n0 <- e[xPretarget,]
e_n2 <- e[xPosttarget,]




#-----------------------------------------------#
# EFFECTS DUE TO EXPERIMENTAL MANIPULATIONS:
#-----------------------------------------------#

#...............................................#
# (1) LMM 1:  n1bb*pvn1
#...............................................'

#------------------------
# WORD N+1
#------------------------

boxcox(gd  ~ n1bb*pvn1, data=d_n1, lambda=seq(-0.5,0.5,length=20))#lbd= -0.3
boxcox(sfd ~ n1bb*pvn1, data=d_n1, lambda=seq(-0.5,0.5,length=10))#lbd= -0.1
boxcox(ffd ~ n1bb*pvn1, data=d_n1, lambda=seq(-0.5,0.5,length=10))#lbd=  0
boxcox(tvt ~ n1bb*pvn1, data=d_n1, lambda=seq(-0.5,0.5,length=10))#lbd= -0.4

# apparently, only for FFD log-transformation (as suggested by lambda = 0)
# is the appropriate transformation to reach a 95% log-likelihood of
# normal distribution ...
#
# for all other fixation duration measures, x^lambda is suggested ...
# INTERESTING: 
# before removing short and long fixation durations from matrix a all
# lambdas have been much closer to 0 and log-transformation was much 
# stronger suggested ...




windows()
#quartz()
par(mfrow=c(1,3))
hist(d_n1$tvt,breaks=100)
hist(log(d_n1$tvt),breaks=100)
hist((d_n1$tvt)^-0.2,breaks=100)


#------------------------------------#
# TABLE 2a:
# word N+1
# DESCRIPTIVE CONDITION MEANS
#------------------------------------#

# (1) FIXATION DURATIONS:
xdat.rs <- melt(d_n1, id=c("id","n1bb","pvn1")
		, measure=c("ffd","sfd","gd","tvt")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")

meanTable <- cast(xdat.rs, n1bb+pvn1 ~ variable
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))
meanTable


# (2) FIXATION PROBABILITIES:
xdat.rs <- melt(e_n1, id=c("id","n1bb","pvn1")
		, measure=c("psk","prx")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")

meanTable <- cast(xdat.rs, n1bb+pvn1 ~ variable
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))
meanTable




#------------------------------------#
# TABLE 2b:
# MAIN ANALYSIS word N+1: 
# LMMS for all dependent variables
#------------------------------------#

# (FFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1 <- lmer(log(ffd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m1 <- lmer(ffd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m1, cor=T)

# (SFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m2 <- lmer(log(sfd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m2 <- lmer(sfd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m2, cor=FALSE)

# (gd)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m3 <- lmer(log(gd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m3 <- lmer(gd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m3, cor=FALSE)

# (TVT)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m4 <- lmer(log(tvt) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m4 <- lmer(tvt ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m4, cor=FALSE)


# (PSK)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m5 <- lmer(psk ~ n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n1, REML=T)
print(m5, cor=FALSE)

# (PRX)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m6 <- lmer(prx ~ n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n1, REML=T)
print(m6, cor=FALSE)



		
#------------------------------------#
# SUPPLEMENTARY word N+1: 
# DISPLAY-CHANGE ANALYSIS:
#------------------------------------#
dc_results <- d_n1$ndcd[match(unique(d_n1$id),d_n1$id)]
table(dc_results)
length(dc_results)
length(which(dc_results==0))	#  7 subjects
length(which(dc_results<=5))  # 13 subjects
length(which(dc_results>5))   # 16 subjects


# (FFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1.2 <- lmer(log(ffd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m1.2 <- lmer(ffd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m1.2, cor=FALSE)
anova(m1, m1.2)  # not better model

# (SFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m2.2 <- lmer(log(sfd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m2.2 <- lmer(sfd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m2.2, cor=FALSE)
anova(m2, m2.2)	# not better model

# (gd)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m3.2 <- lmer(log(gd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m3.2 <- lmer(gd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m3.2, cor=FALSE)
anova(m3, m3.2)	# not better model

# (TVT)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m4.2 <- lmer(log(tvt) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m4.2 <- lmer(tvt ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m4.2, cor=FALSE)
anova(m4, m4.2) 	# not better model in log-transformed TVT

# (PSK)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m5.2 <- lmer(psk ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n1, REML=T)
print(m5.2, cor=FALSE)
anova(m5, m5.2)	# not better model

# (PRX)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m6.2 <- lmer(prx ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n1, REML=T)
print(m6.2, cor=FALSE)
anova(m6, m6.2)	# not better model



#------------------------------------#
# TABLE 3a:
# PRETARGET word N
# DESCRIPTIVE CONDITION MEANS
#------------------------------------#

# (1) FIXATION DURATIONS:
xdat.rs <- melt(d_n0, id=c("id","n1bb","pvn1")
		, measure=c("ffd","sfd","gd","tvt")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")

meanTable <- cast(xdat.rs, n1bb+pvn1 ~ variable
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))
meanTable


# (2) FIXATION PROBABILITIES:
xdat.rs <- melt(e_n0, id=c("id","n1bb","pvn1")
		, measure=c("psk","prx")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")

meanTable <- cast(xdat.rs, n1bb+pvn1 ~ variable
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))
meanTable


#------------------------------------#
# TABLE 3b:
# PRE-BOUNDARY WORD N:
# MAIN ANALYSIS: 
# LMMS for all dependent variables
#------------------------------------#

# (FFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1 <- lmer(log(ffd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m1 <- lmer(ffd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m1, cor=FALSE)

# (SFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m2 <- lmer(log(sfd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m2 <- lmer(sfd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m2, cor=FALSE)

# (gd)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m3 <- lmer(log(gd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m3 <- lmer(gd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m3, cor=FALSE)

# (TVT)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m4 <- lmer(log(tvt) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m4 <- lmer(tvt ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m4, cor=FALSE)


# (PSK)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m5 <- lmer(psk ~ n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n0, REML=T)
print(m5, cor=FALSE)

# (PRX)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m6 <- lmer(prx ~ n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n0, REML=T)
print(m6, cor=FALSE)



#------------------------------------#
# SUPPLEMENTARY word N: 
# DISPLAY-CHANGE ANALYSIS:
#------------------------------------#

# (FFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1.2 <- lmer(log(ffd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m1.2 <- lmer(ffd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m1.2, cor=FALSE)
anova(m1, m1.2)  # not better model

# (SFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m2.2 <- lmer(log(sfd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m2.2 <- lmer(sfd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m2.2, cor=FALSE)
anova(m2, m2.2)	# not better model

# (gd)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m3.2 <- lmer(log(gd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m3.2 <- lmer(gd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m3.2, cor=FALSE)
anova(m3, m3.2)	# not better model

# (TVT)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m4.2 <- lmer(log(tvt) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m4.2 <- lmer(tvt ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m4.2, cor=FALSE)
anova(m4, m4.2) 	# . marginally better model

# (PSK)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m5.2 <- lmer(psk ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n0, REML=T)
print(m5.2, cor=FALSE)
anova(m5, m5.2)	# not better model

# (PRX)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m6.2 <- lmer(prx ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n0, REML=T)
print(m6.2, cor=FALSE)
anova(m6, m6.2)	# not better model






