# Experiment 2: -- without capitalization (version B)
# boundary manipulation of word n+1
# preview validity:   valid vs. invalid
# preview difficulty: easy (HF) vs. difficult (LF)

# Sarah Risse, May 2012



rm(list=ls())

# INPUT:
q_file <- c("N1FQ_Quest.rda")
s_file <- c("N1FQ_Subjects.rda")
d_file <- c("n1FQ_em_filtered.rda")
a_file <- c("n1FQ_a_filtered.rda")

# LIBRARIES:
library(lme4)
library(reshape)


# FUNCTIONS:
source("remef.R")
source("parseq_fast.R")

# LOAD DATA:
load(q_file)	# quest
load(s_file)	# subjects
load(d_file)	# em
load(a_file)	# a



#------------------------------------
# DISPLAY CHANGE DETECTION :
# select participants
#------------------------------------


# (1) select Experiment 2:
#----------------------------

xexp2_in_subj  <- which(subjects$exp==1)  # 31 participants
id_e2 <- subjects$id[xexp2_in_subj]		# id's in Experiment 1
xexp2_in_quest <- match(id_e2,quest$id)
dc_e2 <- quest[xexp2_in_quest,]		# their questionnaire results

# (2) check participants display-change detection sensitivity in Exp.1:
#----------------------------------------------------------------------

length(which(dc_e2$f1==0)) 	# 10 noticed nothing
length(which(dc_e2$f1==1)) 	# 21 noticed something

length(which(dc_e2$f1==1 & dc_e2$f2==3)) # 19 out of 21 noticed display changes

display_change_detection <- dc_e2$f3[which(dc_e2$f1==1 & dc_e2$f2==3)]
hist(display_change_detection, breaks=20)
table(display_change_detection)

length(which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 > 5)) # 10/19 noticed 
# more than 5% (equal to 6) display changes during the experiment
length(which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 <= 5)) # 9/19 noticed 
# less than 5% (equal to 6) display changes during the experiment

# (3) select DC full aware and less aware participants:
#---------------------------------------------------------

dc_faware   <- dc_e2$id[which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 > 5)] 
dc_laware <- setdiff(dc_e2$id, dc_faware)

length(dc_faware)		# 10 participants full aware of display changes
length(dc_laware)		# 21 participants less aware ...




# (4) description of full-aware and less-aware groups:
#--------------------------------------------------------

# FULL AWARE:
range(dc_e2$f3[which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 > 5)])
# 10 - 65 % display changes
mean(dc_e2$f3[which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 > 5)]) # 23.5%
sd(dc_e2$f3[which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 > 5)])   # 16.2

# LESS AWARE (not included UNAWARE):
range(dc_e2$f3[which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 <= 5)])
# 0 - 5 % display changes
mean(dc_e2$f3[which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 <= 5)]) # 4.1%
sd(dc_e2$f3[which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 <= 5)])   # 1.5

# (5) select experimental data and add DC information:
#--------------------------------------------------------

#------------------------------------
# for data set "a" (fixation based):
#------------------------------------

val_ids_e2   <- which(is.element(a$id, id_e2)==TRUE)
d <- a[val_ids_e2,] 

# ndcd: ADD NUMBER OF DISPLAY CHANGES PER SUBJECT (in %):
id_dcd <- dc_e2$id[which(dc_e2$f1==1 & dc_e2$f2==3)]
id_ndcd <- dc_e2$f3[which(is.element(dc_e2$id,id_dcd)==T)]
xdc_to_d <- match(d$id, id_dcd)

d$ndcd <- NA
d$ndcd <- id_ndcd[xdc_to_d] 
d$ndcd[which(is.na(d$ndcd)==TRUE)] <- 0 

# gdcd: ADD GROUP OF DISPLAY CHANGES:
# less aware: -0.5
# full aware:  0.5
xla_in_d <- which(is.element(d$id, dc_laware)==TRUE)
xfa_in_d <- which(is.element(d$id, dc_faware)==TRUE)

d$gdcd <- NA
d$gdcd[xla_in_d] <- -0.5   #  less aware
d$gdcd[xfa_in_d] <-  0.5   #  full aware


#------------------------------------
# filter data for target word n+1
#------------------------------------
xt <- which(d$tar==1)
xd_sn_wn    <- 1e2*d$sn + d$wn
xt_sn_wn    <- unique(1e2*d$sn[xt] + d$wn[xt]) # contains 120 target words
xpre_sn_wn  <- xt_sn_wn - 1
xpost_sn_wn <- xt_sn_wn + 1


xTarget     <- which(is.element(xd_sn_wn,xt_sn_wn)==TRUE)
xPretarget  <- which(is.element(xd_sn_wn,xpre_sn_wn)==TRUE)
xPosttarget <- which(is.element(xd_sn_wn,xpost_sn_wn)==TRUE)


d_n1 <- d[xTarget,]
d_n0 <- d[xPretarget,]
d_n2 <- d[xPosttarget,]


#------------------------------------
# for data set "em" (word based):
#------------------------------------

val_ids_e2   <- which(is.element(em$id, id_e2)==TRUE)
e <- em[val_ids_e2,] 

# ndcd: ADD NUMBER OF DISPLAY CHANGES PER SUBJECT (in %):
xdc_to_e <- match(e$id, id_dcd)

e$ndcd <- NA
e$ndcd <- id_ndcd[xdc_to_e] 
e$ndcd[which(is.na(e$ndcd)==TRUE)] <- 0 

# gdcd: ADD GROUP OF DISPLAY CHANGES:
# less aware: -0.5
# full aware:  0.5
xla_in_e <- which(is.element(e$id, dc_laware)==TRUE)
xfa_in_e <- which(is.element(e$id, dc_faware)==TRUE)

e$gdcd <- NA
e$gdcd[xla_in_e] <- -0.5   #  less aware
e$gdcd[xfa_in_e] <-  0.5   #  full aware


#------------------------------------
# filter data for target word n+1
#------------------------------------

xTarget     <- which(e$twx==1)
xPretarget  <- which(e$twx==1)-1
xPosttarget <- which(e$twx==1)+1

e_n1 <- e[xTarget,]
e_n0 <- e[xPretarget,]
e_n2 <- e[xPosttarget,]




#-----------------------------------------------#
# EFFECTS DUE TO EXPERIMENTAL MANIPULATIONS:
#-----------------------------------------------#

#...............................................#
# (1) LMM 1:  n1bb*pvn1
#...............................................'

#------------------------
# WORD N+1
#------------------------

boxcox(gd  ~ n1bb*pvn1, data=d_n1, lambda=seq(-0.5,0.5,length=20))#lbd= -0.1
boxcox(sfd ~ n1bb*pvn1, data=d_n1, lambda=seq(-0.5,0.5,length=10))#lbd=  0
boxcox(ffd ~ n1bb*pvn1, data=d_n1, lambda=seq(-0.5,0.5,length=10))#lbd=  0
boxcox(tvt ~ n1bb*pvn1, data=d_n1, lambda=seq(-0.5,0.5,length=10))#lbd= -0.2

# apparently, log-transformation (as suggested by lambda = 0)
# is the appropriate transformation to reach a 95% log-likelihood of
# normal distribution for almost all fixation duration measures...
#
# only for all tvt, x^-0.2 is suggested ...
# INTERESTING: 
# before removing short and long fixation durations from matrix a all
# lambdas have been much closer to 0 and log-transformation was much 
# stronger suggested ...




windows()
#quartz()
par(mfrow=c(1,3))
hist(d_n1$tvt,breaks=100)
hist(log(d_n1$tvt),breaks=100)
hist((d_n1$tvt)^-0.2,breaks=100)



windows()
#quartz()
par(mfrow=c(1,3))
hist(e_n1$tvt,breaks=100)
hist(log(e_n1$tvt),breaks=100)
hist((e_n1$tvt)^-0.2,breaks=100)


#------------------------------------#
# TABLE 4a:
# word N+1
# DESCRIPTIVE CONDITION MEANS
#------------------------------------#

# (1) FIXATION DURATIONS:
xdat.rs <- melt(d_n1, id=c("id","n1bb","pvn1")
		, measure=c("ffd","sfd","gd","tvt")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")

meanTable <- cast(xdat.rs, n1bb+pvn1 ~ variable
	, function(x) c(M=signif(mean(x),3)
	, CI=1.96*(sd(x)/(length(x)^.5)) ))
meanTable


# (2) FIXATION PROBABILITIES:
xdat.rs <- melt(e_n1, id=c("id","n1bb","pvn1")
		, measure=c("psk","prx")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")

meanTable <- cast(xdat.rs, n1bb+pvn1 ~ variable
	, function(x) c(M=signif(mean(x),3)
	, CI=1.96*(sd(x)/(length(x)^.5)) ))
meanTable



#------------------------------------#
# Table 4b:
# MAIN ANALYSIS word N+1: 
# LMMS for all dependent variables
#------------------------------------#

# (FFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1 <- lmer(log(ffd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m1 <- lmer(ffd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m1, cor=FALSE)

# (SFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m2 <- lmer(log(sfd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m2 <- lmer(sfd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m2, cor=FALSE)

# (gd)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m3 <- lmer(log(gd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m3 <- lmer(gd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m3, cor=FALSE)

# (TVT)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m4 <- lmer(log(tvt) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m4 <- lmer(tvt ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m4, cor=FALSE)


# (PSK)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m5 <- lmer(psk ~ n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n1, REML=T)
print(m5, cor=FALSE)

# (PRX)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m6 <- lmer(prx ~ n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n1, REML=T)
print(m6, cor=FALSE)



		
#------------------------------------#
# SUPPLEMENTARY word N+1: 
# DISPLAY-CHANGE ANALYSIS:
#------------------------------------#
dc_results <- d_n1$ndcd[match(unique(d_n1$id),d_n1$id)]
table(dc_results)
length(dc_results)
length(which(dc_results==0))	# Exp.2: 12 - Exp.1:  7 subjects
length(which(dc_results<=5))  # Exp.2: 21 - Exp.1: 13 subjects
length(which(dc_results>5))   # Exp.2: 10 - Exp.1: 16 subjects


# (FFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1.2 <- lmer(log(ffd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m1.2 <- lmer(ffd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m1.2, cor=FALSE)
anova(m1, m1.2)  # not better model

# (SFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m2.2 <- lmer(log(sfd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m2.2 <- lmer(sfd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m2.2, cor=FALSE)
anova(m2, m2.2)	# not better model

# (gd)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m3.2 <- lmer(log(gd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m3.2 <- lmer(gd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m3.2, cor=FALSE)
anova(m3, m3.2)	# not better model

# (TVT)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m4.2 <- lmer(log(tvt) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
m4.2 <- lmer(tvt ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n1, REML=T)
print(m4.2, cor=FALSE)
anova(m4, m4.2) 	# . marginally better model

# (PSK)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m5.2 <- lmer(psk ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n1, REML=T)
print(m5.2, cor=FALSE)
anova(m5, m5.2)	# not better model

# (PRX)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m6.2 <- lmer(prx ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n1, REML=T)
print(m6.2, cor=FALSE)
anova(m6, m6.2)	# not better model







#----------------------------------------#
# SUPPLEMENTARY ANALYSIS word N+1:
# Fixation position before boundary
#----------------------------------------#

#-----------------------------------------------------
# IDENTIFY FIRST FIXATION AFTER BOUNDARY
#-----------------------------------------------------

# distance between last fixation before boundary and ...
# dBn1:   ... beginning of word n+1 [in letters]
# dEn1:   ... end of word n+1
# dFn1:   ... position of first fixation on word n+1


xid_sn <- 1e3*d$id + d$sn
msn <- parseq_fast(xid_sn)
x1stAB <- c()

for (i in 1:nrow(msn)) {
	tmp <- d$wn[msn[i,1]:msn[i,2]]
	pretarget <- d$tw_n1[msn[i,1]]-1
	xinTmp <- which(tmp>pretarget)[1]
	xinA <- msn[i,1]+xinTmp-1
	x1stAB <- c(x1stAB,xinA)
}

x1stAB <- x1stAB[which(is.na(x1stAB)==FALSE)]

x1stBB <- x1stAB-1
x2ndAB <- x1stAB+1


LetterToB <- d[x1stBB,"l"] - d[x1stBB,"let"]
BeginningWordN1 <- LetterToB + 1
EndingWordN1    <- LetterToB + 1 + d[x1stAB,"l"]
CurrFixWordN1   <- LetterToB + 1 + d[x1stAB,"let"]

xd_id_sn <- unique(1e3*d$id[x1stAB] + d$sn[x1stAB])
xd_n1_id_sn <- 1e3*d_n1$id + d_n1$sn
xd_to_dn1 <- match(xd_n1_id_sn, xd_id_sn)

d_n1$dBn1 <- BeginningWordN1[xd_to_dn1]
d_n1$dEn1 <- EndingWordN1[xd_to_dn1]
d_n1$dFn1 <- CurrFixWordN1[xd_to_dn1]

d_n1$gdBn1 <- ifelse(d_n1$dBn1 <= median(d_n1$dBn1), -0.5, 0.5)



# (DUR)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1.3 <- lmer(log(dur) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d[x1stBB,], REML=T)
m1.3 <- lmer(dur ~ n1bb*pvn1 + (1|id) + (1|sn), data=d[x1stBB,], REML=T)
print(m1.3, cor=FALSE)
anova(m1, m1.3)  # not better model




#------------------------------------#
# TABLE 5a:
# word N+1
# DESCRIPTIVE CONDITION MEANS
#------------------------------------#

# (1) FIXATION DURATIONS:
xdat.rs <- melt(d_n0, id=c("id","n1bb","pvn1")
		, measure=c("ffd","sfd","gd","tvt")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")

meanTable <- cast(xdat.rs, n1bb+pvn1 ~ variable
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))
meanTable


# (2) FIXATION PROBABILITIES:
xdat.rs <- melt(e_n0, id=c("id","n1bb","pvn1")
		, measure=c("psk","prx")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")

meanTable <- cast(xdat.rs, n1bb+pvn1 ~ variable
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))
meanTable




#------------------------------------#
# Table 5b:
# PRE-BOUNDARY WORD N:
# MAIN ANALYSIS: 
# LMMS for all dependent variables
#------------------------------------#

# (FFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1 <- lmer(log(ffd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m1 <- lmer(ffd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m1, cor=FALSE)

# (SFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m2 <- lmer(log(sfd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m2 <- lmer(sfd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m2, cor=FALSE)

# (gd)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m3 <- lmer(log(gd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m3 <- lmer(gd ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m3, cor=FALSE)

# (TVT)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m4 <- lmer(log(tvt) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m4 <- lmer(tvt ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m4, cor=FALSE)


# (PSK)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m5 <- lmer(psk ~ n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n0, REML=T)
print(m5, cor=FALSE)

# (PRX)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m6 <- lmer(prx ~ n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n0, REML=T)
print(m6, cor=FALSE)




#------------------------------------#
# SUPPLEMENTARY word N: 
# DISPLAY-CHANGE ANALYSIS:
#------------------------------------#

# (FFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m1.2 <- lmer(log(ffd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m1.2 <- lmer(ffd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m1.2, cor=FALSE)
anova(m1, m1.2)  # not better model

# (SFD)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m2.2 <- lmer(log(sfd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m2.2 <- lmer(sfd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m2.2, cor=FALSE)
anova(m2, m2.2)	# not better model

# (gd)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m3.2 <- lmer(log(gd) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m3.2 <- lmer(gd ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m3.2, cor=FALSE)
anova(m3, m3.2)	# not better model

# (TVT)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m4.2 <- lmer(log(tvt) ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
m4.2 <- lmer(tvt ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), data=d_n0, REML=T)
print(m4.2, cor=FALSE)
anova(m4, m4.2) 	# . marginally better model

# (PSK)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m5.2 <- lmer(psk ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n0, REML=T)
print(m5.2, cor=FALSE)
anova(m5, m5.2)	# not better model

# (PRX)-INCLUDE CONTINUOUS PREDICTOR ndcd:
m6.2 <- lmer(prx ~ gdcd*n1bb*pvn1 + (1|id) + (1|sn), family=binomial, data=e_n0, REML=T)
print(m6.2, cor=FALSE)
anova(m6, m6.2)	# not better model





#----------------------------------------#
# FIGURE 2:
# word N
# COMPARISON FFD AND GD FOR DC-DETECTION
#----------------------------------------#

windows(1,width=6, height=4, pointsize=10)
#quartz(1, width=8, height=8, pointsize=10)
par(mfrow=c(1,2),lwd=2, cex.axis=1.2, cex.lab=1.2, cex.main=1.4, mar=c(5,4.2,2.5,2.5))

################################################
# FIGURE #2a:   FFD - High vs. Low DC-detection
################################################

# GROUP "less aware of display changes":
# >> 13 subjects ...
m1.1 <- lmer(log(ffd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0[which(d_n0$gdcd==-0.5),])

dat <- m1.1@frame
# keep=FALSE means that fixed and random effect variance specified 
# is removed from the dependent variable...
dat$ffd.adj <- remef(m1.1, keep=FALSE, grouping=FALSE, fix = c(), ran = list(c(1),c(1)))


# descriptives/ effect sizes:
xdat.rs <- melt(dat, id=c("id","n1bb","pvn1")
		, measure=c("ffd.adj")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")


mPlot <- cast(xdat.rs, n1bb ~ variable
	, subset=variable==c("ffd.adj")
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))


mPlot$lower <- mPlot[,2] - mPlot[,3]
mPlot$upper <- mPlot[,2] + mPlot[,3]

data  <- t(as.matrix(mPlot[,2]))
lower <- t(as.matrix(mPlot[,4]))
upper <- t(as.matrix(mPlot[,5]))

# GROUP "full aware of display changes":
# >> 16 subjects ...
m1.2 <- lmer(log(ffd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0[which(d_n0$gdcd== 0.5),])

dat <- m1.2@frame
# keep=FALSE means that fixed and random effect variance specified 
# is removed from the dependent variable...
dat$ffd.adj <- remef(m1.2, keep=FALSE, grouping=FALSE, fix = c(), ran = list(c(1),c(1)))


# descriptives/ effect sizes:
xdat.rs <- melt(dat, id=c("id","n1bb","pvn1")
		, measure=c("ffd.adj")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")


mPlot <- cast(xdat.rs, n1bb ~ variable
	, subset=variable==c("ffd.adj")
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))

mPlot$lower <- mPlot[,2] - mPlot[,3]
mPlot$upper <- mPlot[,2] + mPlot[,3]

data  <- rbind(data,t(as.matrix(mPlot[,2])))
lower <- rbind(lower,t(as.matrix(mPlot[,4])))
upper <- rbind(upper,t(as.matrix(mPlot[,5])))

y.limits <- c(5.3,5.6)

plot(c(1,2),data[1:2], type='b',lty='solid'
	, pch=21
	, bg='black'
	, ylim=y.limits
	, xlim=c(0.8,2.2)
	, ylab=c('First fixation duration [ms]')
	, xlab=c('N+1 preview difficulty')
	, axes=F)
	axis(side=1, at=c(1,2), labels=c("easy","difficult")
	, tick=T)
	axis(side=2, at=c(5.3, 5.4, 5.5, 5.6), labels=c("200","221","245","270"), tick=T)
	abline(v = c(1,1.5,2),h = seq(y.limits[1],y.limits[2],0.1)
	, col = "gray"
	, lty = "dotted", lwd=1)
	errbar(c(1,2),data[1:2], yplus=upper[1:2]
	, yminus=lower[1:2], add=T, col="black", lty="solid"
	, lwd=1.6)
	errbar(c(1,2),data[3:4], yplus=upper[3:4]
	, yminus=lower[3:4], add=T, col="black", lty="solid"
	, lwd=1.6)
	lines(c(1,2),data[3:4], type='b', lty='dashed'
	, pch=21, bg='white', cex=1.8)
	lines(c(1,2),data[1:2], type='b', lty='solid'
	, pch=21, bg='black', cex=1.8)	
	box(lty='solid')

	legend(0.78,5.6, legend=c("Group 1: low", "Group 2: high")
	, title=c("DC detection")
	, lty=c('solid','dashed')
	, pch=c(21,21)
	, pt.bg=c('black','white')
	, merge=F
	, ncol=1.2, bty='o'
	, bg='white'
	, box.col='white', box.lwd=1, cex=1.1)


################################################
# FIGURE #2b:   GD  -  High vs. LOW DC-detection
################################################

# GROUP "less aware of display changes":
# >> 13 subjects ...
m1.1 <- lmer(log(gd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0[which(d_n0$gdcd==-0.5),])

dat <- m1.1@frame
# keep=FALSE means that fixed and random effect variance specified 
# is removed from the dependent variable...
dat$gd.adj <- remef(m1.1, keep=FALSE, grouping=FALSE, fix = c(), ran = list(c(1),c(1)))


# descriptives/ effect sizes:
xdat.rs <- melt(dat, id=c("id","n1bb","pvn1")
		, measure=c("gd.adj")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")


mPlot <- cast(xdat.rs, n1bb ~ variable
	, subset=variable==c("gd.adj")
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))


mPlot$lower <- mPlot[,2] - mPlot[,3]
mPlot$upper <- mPlot[,2] + mPlot[,3]

data  <- t(as.matrix(mPlot[,2]))
lower <- t(as.matrix(mPlot[,4]))
upper <- t(as.matrix(mPlot[,5]))

# GROUP "full aware of display changes":
# >> 16 subjects ...
m1.2 <- lmer(log(gd) ~ n1bb*pvn1 + (1|id) + (1|sn), data=d_n0[which(d_n0$gdcd== 0.5),])

dat <- m1.2@frame
# keep=FALSE means that fixed and random effect variance specified 
# is removed from the dependent variable...
dat$gd.adj <- remef(m1.2, keep=FALSE, grouping=FALSE, fix = c(), ran = list(c(1),c(1)))


# descriptives/ effect sizes:
xdat.rs <- melt(dat, id=c("id","n1bb","pvn1")
		, measure=c("gd.adj")
		, na.rm=TRUE)

xdat.rs$n1bb <- as.factor(xdat.rs$n1bb)
levels(xdat.rs$n1bb) <- c("HF","LF")

xdat.rs$pvn1 <- as.factor(xdat.rs$pvn1)
levels(xdat.rs$pvn1) <- c("valid","invalid")


mPlot <- cast(xdat.rs, n1bb ~ variable
	, subset=variable==c("gd.adj")
	, function(x) c(M=signif(mean(x),3)
	, SE=1.96*(sd(x)/(length(x)^.5)) ))

mPlot$lower <- mPlot[,2] - mPlot[,3]
mPlot$upper <- mPlot[,2] + mPlot[,3]

data  <- rbind(data,t(as.matrix(mPlot[,2])))
lower <- rbind(lower,t(as.matrix(mPlot[,4])))
upper <- rbind(upper,t(as.matrix(mPlot[,5])))

y.limits <- c(5.3,5.6)

plot(c(1,2),data[1:2], type='b',lty='solid'
	, pch=21
	, bg='black'
	, ylim=y.limits
	, xlim=c(0.8,2.2)
	, ylab=c('Gaze duration [ms]')
	, xlab=c('N+1 preview difficulty')
	, log="y"
	, axes=F)
	axis(side=1, at=c(1,2), labels=c("easy","difficult")
	, tick=T)
	axis(side=2, at=c(5.3, 5.4, 5.5, 5.6), labels=c("200","221","245","270"), tick=T)
	abline(v = c(1,1.5,2),h = seq(y.limits[1],y.limits[2],0.1)
	, col = "gray"
	, lty = "dotted", lwd=1)
	errbar(c(1,2),data[1:2], yplus=upper[1:2]
	, yminus=lower[1:2], add=T, col="black", lty="solid"
	, lwd=1.6)
	errbar(c(1,2),data[3:4], yplus=upper[3:4]
	, yminus=lower[3:4], add=T, col="black", lty="solid"
	, lwd=1.6)
	lines(c(1,2),data[3:4], type='b', lty='dashed'
	, pch=21, bg='white', cex=1.8)
	lines(c(1,2),data[1:2], type='b', lty='solid'
	, pch=21, bg='black', cex=1.8)	
	box(lty='solid')




