# Experiment 1: -- with capitalization (version A)
# Experiment 2: -- without capitalization (version B)
# boundary manipulation of word n+1
# preview validity:   valid vs. invalid
# preview difficulty: easy (HF) vs. difficult (LF)

# Sarah Risse, October 2012

# Quantile regression:
# Look at the time course of the two preview effects (preview benefit
# and delayed PoF effect) on word n+1



rm(list=ls())

# INPUT:
q_file <- c("N1FQ_Quest.rda")
s_file <- c("N1FQ_Subjects.rda")
d_file <- c("n1FQ_em_filtered.rda")
a_file <- c("n1FQ_a_filtered.rda")

# LIBRARIES:
library(lme4)
library(reshape)


# FUNCTIONS:
source("remef.R")
source("parseq_fast.R")

# LOAD DATA:
load(q_file)	# quest
load(s_file)	# subjects
load(d_file)	# em
load(a_file)	# a


#------------------------------------
# DISPLAY CHANGE DETECTION :
# select participants
#------------------------------------

# (1) select Experiment 1:
#----------------------------

xexp1_in_subj  <- which(subjects$exp==0)  # 29 participants
id_e1 <- subjects$id[xexp1_in_subj]		# id's in Experiment 1
xexp1_in_quest <- match(id_e1,quest$id)
dc_e1 <- quest[xexp1_in_quest,]		# their questionnaire results


val_ids_e1   <- which(is.element(a$id, id_e1)==TRUE)
a$exp[val_ids_e1] <- 0 



# (1) select Experiment 2:
#----------------------------

xexp2_in_subj  <- which(subjects$exp==1)  # 31 participants
id_e2 <- subjects$id[xexp2_in_subj]		# id's in Experiment 1
xexp2_in_quest <- match(id_e2,quest$id)
dc_e2 <- quest[xexp2_in_quest,]		# their questionnaire results

val_ids_e2   <- which(is.element(a$id, id_e2)==TRUE)
a$exp[val_ids_e2] <- 1 



# DISPLAY CHANGE SENSITIVITY:
#--------------------------------

dc_faware1 <- dc_e1$id[which(dc_e1$f1==1 & dc_e1$f2==3 & dc_e1$f3 > 5)] 
dc_laware1 <- setdiff(dc_e1$id, dc_faware1)

dc_faware2 <- dc_e2$id[which(dc_e2$f1==1 & dc_e2$f2==3 & dc_e2$f3 > 5)] 
dc_laware2 <- setdiff(dc_e2$id, dc_faware2)

dc_faware <- c(dc_faware1, dc_faware2)
dc_laware <- c(dc_laware1, dc_laware2)


# gdcd: ADD GROUP OF DISPLAY CHANGES:
# less aware: -0.5
# full aware:  0.5
xla_in_a <- which(is.element(a$id, dc_laware)==TRUE)
xfa_in_a <- which(is.element(a$id, dc_faware)==TRUE)

a$gdcd <- NA
a$gdcd[xla_in_a] <- -0.5   #  less aware
a$gdcd[xfa_in_a] <-  0.5   #  full aware

d <- a

#------------------------------------
# filter data for target word n+1
#------------------------------------
xt <- which(d$tar==1)
xd_sn_wn    <- 1e2*d$sn + d$wn
xt_sn_wn    <- unique(1e2*d$sn[xt] + d$wn[xt]) # contains 120 target words
xpre_sn_wn  <- xt_sn_wn - 1
xpost_sn_wn <- xt_sn_wn + 1


xTarget     <- which(is.element(xd_sn_wn,xt_sn_wn)==TRUE)
xPretarget  <- which(is.element(xd_sn_wn,xpre_sn_wn)==TRUE)
xPosttarget <- which(is.element(xd_sn_wn,xpost_sn_wn)==TRUE)


d_n1 <- d[xTarget,]
d_n0 <- d[xPretarget,]
d_n2 <- d[xPosttarget,]


#----------------------------------------#
# SUPPLEMENTARY ANALYSIS:
# Quantile regression analysis:
#----------------------------------------#

library(quantreg)

# DECISION:
# ... compute supplementary analysis with ffd to be analogous to
# ... Reingold et al. (2012)
# ... sfd: 4140 cases, ffd: 4418 
# ... most ffd on word n+1 are single fixation cases


# QUANTILE REGRESSION MODEL:
# ... 10 quantiles are selected and the change in n1bb and pvn1
# ... parameters of the models are compared within a plot
tau_seq <- seq(from=0.09, to=0.99, by=0.10)
qr1 <- rq(log(ffd) ~ n1bb*pvn1, tau=tau_seq, data=d_n1) 
summary(qr1)



# FAQ:
# http://www.econ.uiuc.edu/~roger/research/rq/FAQ
#6.  [Confidence Intervals]  "Why does summary(rq(...)) sometimes produce a
#table with upper and lower confidence limits, and sometimes a table with standard
#errors?"
#   There are several methods for computing standard errors and confidence limits.
#   By default on small problems (n < 1001)  summary uses the rank inversion method,
#   which produces (potentially asymmetric) confidence intervals,while for larger 
#   problems the default is to estimate the asymptotic covariance matrix and
#   report standard errors of the parameter estimates.


# PLOT SLOPE CHANGES OF QUANTILE REGRESSION:
windows(height=6, width=6)
#quartz(height=4.5, width=4, pointsize=10)

coefTab <- c()

for (i in 1:length(tau_seq))  {

	qrCoef   <- as.data.frame(summary(qr1)[[i]]$coefficients)
	coefTab <- as.data.frame(rbind(coefTab,c(qrCoef$"Value"[2]
		, qrCoef$"Std. Error"[2], qrCoef$"Value"[3], qrCoef$"Std. Error"[3]
		, qrCoef$"Pr(>|t|)"[2], qrCoef$"Pr(>|t|)"[3])))
}

colnames(coefTab) <- c("n1bb_b", "n1bb_SE", "pvn1_b", "pvn1_SE", "n1bb_p", "pvn1_p")

coefTab2 <- c()

for (i in 1:length(tau_seq))  {

	qrCoef   <- as.data.frame(summary(qr1)[[i]]$coefficients)
	coefTab2 <- as.data.frame(rbind(coefTab2,c(qrCoef$"Value"[2]
		, qrCoef$"Std. Error"[2], qrCoef$"Value"[3], qrCoef$"Std. Error"[3]
		, qrCoef$"Value"[4], qrCoef$"Std. Error"[4]
		, qrCoef$"Pr(>|t|)"[2], qrCoef$"Pr(>|t|)"[3], qrCoef$"Pr(>|t|)"[4])))
}

colnames(coefTab2) <- c("n1bb_b", "n1bb_SE", "pvn1_b", "pvn1_SE"
	, "n1ab_b", "n1ab_SE", "n1bb_p", "pvn1_p", "n1ab_p")



ymax <- round(max(coefTab2[,1:6])+0.05, digits=1)
ymin <- round(min(coefTab2[,1:6])-0.05, digits=1)

x1 <- c(tau_seq)
y1 <- coefTab2$n1bb_b
y2 <- coefTab2$pvn1_b
y3 <- coefTab2$n1ab_b

plot(x1,y1, lwd=2, type="l", col="aquamarine4"
	, xlim=c(0,1)
	, ylim=c(ymin,ymax)
	, xlab=c("Fixation quantiles of log(FFD)")
	, ylab=c("Estimated slope [b]")
	, axes=F)
axis(side=2, pos=0)
axis(side=1, pos=ymin)

# Quantile borders:
for (i in 1:length(tau_seq))  {
	lines(c(tau_seq[i],tau_seq[i]), c(ymin,ymax), col="grey")
}

# Zero line:
lines(x=c(0,1), y=c(0,0), lwd=2, col="grey")

lines(x1, y1, lwd=2, type="l", col="aquamarine4")
lines(x1, y2, lwd=2, type="l", col="darkred")
lines(x1, y3, lwd=2, type="l", col="gold4")

xx <- c(tau_seq, rev(tau_seq))
yy1 <- c(y1+coefTab2$n1bb_SE, rev(y1-coefTab2$n1bb_SE))
yy2 <- c(y2+coefTab2$pvn1_SE, rev(y2-coefTab2$pvn1_SE))
yy3 <- c(y3+coefTab2$n1ab_SE, rev(y3-coefTab2$n1ab_SE))
polygon(xx,yy1,col=rgb( 69,139,116,alpha=100,maxColorValue=255), border=NA)
polygon(xx,yy2,col=rgb(224,102,114,alpha=100,maxColorValue=255), border=NA)
polygon(xx,yy3,col=rgb(255,215,0,alpha=100,maxColorValue=255), border=NA)


legend(0,ymax
	, legend=c("Preview difficulty (pvD)","Preview validity   (pvV)"
	, "Target difficulty (tD)")
	, lty=c("solid","solid","solid")
	, col=c("aquamarine4","darkred","gold4")
	, lwd=c(2,2,2)
	, merge=F
	, ncol=1.2,cex=1
	, bty="o", bg="white", box.col="white")

# plot box around plot:
rect(xleft=0, ybottom=ymin, xright=1, ytop=ymax, lwd=2)

# plot bottom rectangle for significance symbols:
rect(xleft=0, ybottom=ymin, xright=1, ytop=ymin+0.05, lwd=2, col="cornsilk2")

for (i in 1:length(tau_seq))  {
	if(coefTab2$n1bb_p[i] > 0.05) pSymbol1 <- c("")
	if(coefTab2$pvn1_p[i] > 0.05) pSymbol2 <- c("")
	if(coefTab2$n1ab_p[i] > 0.05) pSymbol3 <- c("")
	if(coefTab2$n1bb_p[i] <= 0.05 & coefTab2$n1bb_p[i] > 0.01) pSymbol1 <- c("*")
	if(coefTab2$pvn1_p[i] <= 0.05 & coefTab2$pvn1_p[i] < 0.01) pSymbol2 <- c("*")
	if(coefTab2$n1ab_p[i] <= 0.05 & coefTab2$n1ab_p[i] < 0.01) pSymbol3 <- c("*")
	if(coefTab2$n1bb_p[i] <= 0.01 & coefTab2$n1bb_p[i] > 0.001) pSymbol1 <- c("**")
	if(coefTab2$pvn1_p[i] <= 0.01 & coefTab2$pvn1_p[i] < 0.001) pSymbol2 <- c("**")
	if(coefTab2$n1ab_p[i] <= 0.01 & coefTab2$n1ab_p[i] < 0.001) pSymbol3 <- c("**")
	if(coefTab2$n1bb_p[i] <= 0.001) pSymbol1 <- c("***")
	if(coefTab2$pvn1_p[i] <= 0.001) pSymbol2 <- c("***")
	if(coefTab2$n1ab_p[i] <= 0.001) pSymbol3 <- c("***")
text(x=tau_seq[i]-0.05, y=-0.16, labels=pSymbol1, col="aquamarine4", lwd=2)
text(x=tau_seq[i]-0.05, y=-0.17, labels=pSymbol2, col="darkred", lwd=2)
text(x=tau_seq[i]-0.05, y=-0.18, labels=pSymbol3, col="gold4", lwd=2)
}

#----------------------------------------------------
# repeated measures quantile regression
#----------------------------------------------------
# ... QR for each participant separately:
# ... simulates repeated measures QR!!
# ... advice from Reinhold, see x6_QuantReg.RK.R
qr1.id <- by(d_n1, d_n1$id, function(x) 
	rq(log(ffd) ~ n1bb*pvn1, tau=tau_seq, data=x))


# ... CHECK results in QR-summary:
# ... for the last quantile (0.89-0.99) the lower and upper bounds of the estimated coefficients are
# ... surprisingly high and this for all (?) participants.
# ... This may suggest that the estimations in this quantile are not reliable on individual subject level.
summary(qr1.id[[1]])
summary(qr1.id[[16]])
summary(qr1.id[[26]])


tab_n1bb <- c()
tab_pvn1 <- c()
for (i in (1:dim(qr1.id)))  {
	tmp <- qr1.id[[i]]$coefficients
	tab_n1bb <- rbind(tab_n1bb, tmp[2,])
	tab_pvn1 <- rbind(tab_pvn1, tmp[3,])
}

mn_n1bb <- colMeans(tab_n1bb)
sd_n1bb <- apply(tab_n1bb, 2, sd)
ci_n1bb <- 1.96*(sd_n1bb/nrow(tab_n1bb)^.5)

mn_pvn1 <- colMeans(tab_pvn1)
sd_pvn1 <- apply(tab_pvn1, 2, sd)
ci_pvn1 <- 1.96*(sd_pvn1/nrow(tab_pvn1)^.5)


#######################################
# Figure 3
#######################################

# PLOT SLOPE CHANGES OF QUANTILE REGRESSION:
windows(height=4.5, width=4)
#quartz(height=4.5, width=4, pointsize=10)


ymax <- round(max(mn_n1bb, mn_pvn1)+0.15, digits=1)
ymin <- round(min(mn_n1bb, mn_pvn1)-0.08, digits=2)

xmin <- 0.05
xmax <- 1.05

x1 <- c(tau_seq)+0.01
y1 <- mn_n1bb
y2 <- mn_pvn1

plot(x1,y1, lwd=2, type="l", col="aquamarine4"
	, xlim=c(xmin,xmax)
	, ylim=c(ymin,ymax)
	, xlab=c("Fixation quantiles of log(FFD)")
	, ylab=c("Estimated slope [b]")
	, axes=F)
axis(side=2, pos=xmin, at=c(-0.10,-0.05,0.00,0.05,0.10,0.15,0.20)
	, labels=c("","","0","0.05","0.1","0.15",""))
axis(side=1, pos=ymin, at=c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1.0)
	, labels=c("1","2","3","4","5","6","7","8","9","10"))

# Quantile borders:
for (i in 1:length(tau_seq))  {
	lines(c(tau_seq[i]+0.01,tau_seq[i]+0.01), c(ymin,ymax), col="grey")
}

# Zero line:
lines(x=c(xmin,xmax), y=c(0,0), lwd=2, col="grey")

lines(x1, y1, lwd=2, type="l", col="aquamarine4")
lines(x1, y2, lwd=2, type="l", col="darkred")

xx <- c(tau_seq+0.01, rev(tau_seq+0.01))
yy1 <- c(y1+ci_n1bb, rev(y1-ci_n1bb))
yy2 <- c(y2+ci_pvn1, rev(y2-ci_pvn1))
polygon(xx,yy1,col=rgb( 69,139,116,alpha=100,maxColorValue=255), border=NA)
polygon(xx,yy2,col=rgb(224,102,114,alpha=100,maxColorValue=255), border=NA)


legend(xmin,ymax
	, legend=c("Preview difficulty (pvD)","Preview validity   (pvV)")
	, lty=c("solid","solid")
	, col=c("aquamarine4","darkred")
	, lwd=c(2,2)
	, merge=F
	, ncol=1.2,cex=1
	, bty="o", bg="white", box.col="white")

# plot box around plot:
rect(xleft=xmin, ybottom=ymin, xright=xmax, ytop=ymax, lwd=2)

# plot bottom rectangle for significance symbols:
rect(xleft=xmin, ybottom=ymin, xright=xmax, ytop=-0.02, lwd=2, col="cornsilk2")

title(main=c("Time course of preview effects"))

for (i in 1:length(tau_seq))  {
	if(coefTab$n1bb_p[i] > 0.05) pSymbol1 <- c("")
	if(coefTab$pvn1_p[i] > 0.05) pSymbol2 <- c("")
	if(coefTab$n1bb_p[i] <= 0.05 & coefTab$n1bb_p[i] > 0.01) pSymbol1 <- c("*")
	if(coefTab$pvn1_p[i] <= 0.05 & coefTab$pvn1_p[i] < 0.01) pSymbol2 <- c("*")
	if(coefTab$n1bb_p[i] <= 0.01 & coefTab$n1bb_p[i] > 0.001) pSymbol1 <- c("**")
	if(coefTab$pvn1_p[i] <= 0.01 & coefTab$pvn1_p[i] < 0.001) pSymbol2 <- c("**")
	if(coefTab$n1bb_p[i] <= 0.001) pSymbol1 <- c("***")
	if(coefTab$pvn1_p[i] <= 0.001) pSymbol2 <- c("***")
text(x=tau_seq[i]+0.01, y=-0.03, labels=pSymbol1, col="aquamarine4", lwd=2)
text(x=tau_seq[i]+0.01, y=-0.04, labels=pSymbol2, col="darkred", lwd=2)
}

# ------------------------
# Re-transformation of FFD-quantiles into ms
# ------------------------
library(gtools)
tseq <- c(0,tau_seq)
levels(quantcut(log(d_n1$ffd), tseq))

exp(3.91)  # 0)   50 ms
exp(4.97)  # 1)  144 ms
exp(5.11)  # 2)  166 ms
exp(5.2)   # 3)  181 ms
exp(5.3)   # 4)  200 ms
exp(5.38)  # 5)  217 ms
exp(5.46)  # 6)  235 ms
exp(5.55)  # 7)  257 ms
exp(5.66)  # 8)  287 ms
exp(5.82)  # 9)  337 ms
exp(6.29)  # 10) 539 ms

quantiles.id <- by(log(d_n1$ffd), d_n1$id, function(x) 
	levels(quantcut(x, tseq)))

quantiles.id[1]
quantiles.id[2]

